@@ -4,12 +4,10 @@
 #' `collapseCohorts()` concatenates cohort records, allowing for some number
 #' of days between one finishing and the next starting.
 #'
-#' @param cohort A cohort table
-#' @param cohortId IDs of the cohorts to modify. If NULL, all cohorts will be
-#' used; otherwise, only the specified cohorts will be modified, and the
-#' rest will remain unchanged.
-#' @param gap Number of days to use when merging cohort entries.
-#' @param name Name of the cohort table.
+#' @inheritParams cohortDoc
+#' @inheritParams cohortIdModifyDoc
+#' @inheritParams gapDoc
+#' @inheritParams nameDoc
 #'
 #' @export
 #'
@@ -19,25 +17,23 @@ collapseCohorts <- function(cohort,
                             cohortId = NULL,
                             gap = 0,
                             name = tableName(cohort)) {
-
   # input validation
-  cdm <- omopgenerics::cdmReference(cohort)
-  validateCDM(cdm)
   cohort <- validateCohortTable(cohort, dropExtraColumns = TRUE)
+  name <- omopgenerics::validateNameArgument(name, validation = "warning")
+  cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
+  cohortId <- validateCohortId(cohortId, settings(cohort))
+  omopgenerics::assertNumeric(gap, integerish = TRUE, min = 0, length = 1)
   ids <- settings(cohort)$cohort_definition_id
-  cohortId <- validateCohortId(cohortId, ids)
-  gap <- validateGap(gap)
 
   # temp tables
   tablePrefix <- omopgenerics::tmpPrefix()
-  tmpNewCohort <- omopgenerics::uniqueTableName(tablePrefix)
-
+  tmpNewCohort <- paste0(omopgenerics::uniqueTableName(tablePrefix), "_1")
   if (all(ids %in% cohortId)) {
     newCohort <- cohort |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE) |>
       omopgenerics::newCohortTable(.softValidation = TRUE)
   } else {
-    tmpUnchanged <- omopgenerics::uniqueTableName(tablePrefix)
+    tmpUnchanged <- paste0(omopgenerics::uniqueTableName(tablePrefix), "_2")
     unchangedCohort <- cohort |>
       dplyr::filter(!.data$cohort_definition_id %in% .env$cohortId) |>
       dplyr::compute(name = tmpUnchanged, temporary = FALSE)
@@ -45,24 +41,46 @@ collapseCohorts <- function(cohort,
       dplyr::filter(.data$cohort_definition_id %in% .env$cohortId) |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE)
   }
-
-  if (gap > 0) {
-    newCohort <- newCohort |> joinOverlap(gap = gap)
+  if (gap == Inf) {
+    newCohort <- newCohort |>
+      PatientProfiles::addObservationPeriodId() |>
+      joinAll(by = c(
+        "cohort_definition_id",
+        "subject_id",
+        "observation_period_id"
+      )) |>
+      dplyr::select(!"observation_period_id")
+  } else if (gap > 0) {
+    newCohort <- newCohort |>
+      PatientProfiles::addObservationPeriodId() |>
+      joinOverlap(
+        name = tmpNewCohort,
+        gap = gap,
+        by = c(
+          "cohort_definition_id",
+          "subject_id",
+          "observation_period_id"
+        )
+      ) |>
+      dplyr::select(!"observation_period_id")
   }
-
   if (!all(ids %in% cohortId)) {
-    newCohort <- unchangedCohort |> dplyr::union_all(newCohort)
+    newCohort <- unchangedCohort |>
+      dplyr::union_all(newCohort)|>
+      dplyr::compute(name = name, temporary = FALSE)
+  } else {
+    newCohort <- newCohort |>
+      dplyr::compute(name = name, temporary = FALSE)
   }
-
   newCohort <- newCohort |>
-    dplyr::compute(name = name, temporary = FALSE) |>
     omopgenerics::newCohortTable(.softValidation = TRUE) |>
     omopgenerics::recordCohortAttrition(
       reason = "Collapse cohort with a gap of {gap} days.",
-      cohortId = cohortId
-    )
+      cohortId = cohortId)
 
   omopgenerics::dropTable(cdm = cdm, name = dplyr::starts_with(tablePrefix))
 
   return(newCohort)
 }
+
+
