@@ -5,18 +5,16 @@
 #' that an individual is seen (or not seen) to have a death in some time
 #' window around an index date.
 #'
-#' @param cohort A cohort table in a cdm reference.
-#' @param window Window to consider events over.
-#' @param cohortId IDs of the cohorts to modify. If NULL, all cohorts will be
-#' used; otherwise, only the specified cohorts will be modified, and the
-#' rest will remain unchanged.
-#' @param indexDate Variable in x that contains the date to compute the
-#' intersection.
+#' @inheritParams cohortDoc
+#' @inheritParams cohortIdModifyDoc
+#' @inheritParams windowDoc
+#' @inheritParams nameDoc
+#' @param indexDate Name of the column in the cohort that contains the date to
+#' use as time 0 for window days.
 #' @param censorDate Whether to censor overlap events at a specific date or a
-#' column date of x.
+#' column date of the cohort.
 #' @param negate If set as TRUE, criteria will be applied as exclusion
 #' rather than inclusion (i.e. require absence in another cohort).
-#' @param name Name of the new cohort with the future observation restriction.
 #'
 #' @return Cohort table with only those with a death event kept (or without
 #' if negate = TRUE)
@@ -39,26 +37,26 @@ requireDeathFlag <- function(cohort,
                              negate = FALSE,
                              name = tableName(cohort)) {
   # checks
-  name <- validateName(name)
-  assertLogical(negate, length = 1)
-  validateCohortTable(cohort)
-  cdm <- omopgenerics::cdmReference(cohort)
-  validateCDM(cdm)
+  name <- omopgenerics::validateNameArgument(name, validation = "warning")
+  cohort <- omopgenerics::validateCohortArgument(cohort)
   validateCohortColumn(indexDate, cohort, class = "Date")
-  ids <- omopgenerics::settings(cohort)$cohort_definition_id
-  cohortId <- validateCohortId(cohortId, ids)
+  cdm <- omopgenerics::validateCdmArgument(omopgenerics::cdmReference(cohort))
+  cohortId <- validateCohortId(cohortId, settings(cohort))
+  window <- omopgenerics::validateWindowArgument(window)
+  omopgenerics::assertLogical(negate, length = 1)
 
-  cols <- unique(c("cohort_definition_id", "subject_id",
-                   "cohort_start_date", "cohort_end_date",
-                   indexDate))
+  cols <- unique(
+    c(
+      "cohort_definition_id",
+      "subject_id",
+      "cohort_start_date",
+      "cohort_end_date",
+      indexDate
+    )
+  )
 
-  if(is.list(window)){
-    window_start <- window[[1]][1]
-    window_end <- window[[1]][2]
-  } else {
-    window_start <- window[1]
-    window_end <- window[2]
-  }
+  window_start <- window[[1]][1]
+  window_end <- window[[1]][2]
 
   subsetCohort <- cohort %>%
     dplyr::select(dplyr::all_of(.env$cols)) %>%
@@ -69,12 +67,10 @@ requireDeathFlag <- function(cohort,
       deathFlagName = "death"
     )
 
-  if(isFALSE(negate)){
+  if (isFALSE(negate)) {
     subsetCohort <- subsetCohort %>%
-      dplyr::filter(
-        .data$death == 1 |
-          (!.data$cohort_definition_id %in% cohortId)
-      ) %>%
+      dplyr::filter(.data$death == 1 |
+                      (!.data$cohort_definition_id %in% cohortId)) %>%
       dplyr::select(!"death")
     # attrition reason
     reason <- glue::glue("Death between {window_start} & ",
@@ -82,10 +78,8 @@ requireDeathFlag <- function(cohort,
   } else {
     # ie require absence instead of presence
     subsetCohort <- subsetCohort %>%
-      dplyr::filter(
-        .data$death != 1 |
-          (!.data$cohort_definition_id %in% cohortId)
-      ) %>%
+      dplyr::filter(.data$death != 1 |
+                      (!.data$cohort_definition_id %in% cohortId)) %>%
       dplyr::select(!"death")
     # attrition reason
     reason <- glue::glue("Alive between {window_start} & ",
@@ -97,8 +91,7 @@ requireDeathFlag <- function(cohort,
   }
 
   x <- cohort %>%
-    dplyr::inner_join(subsetCohort,
-                      by = c(cols)) %>%
+    dplyr::inner_join(subsetCohort, by = c(cols)) %>%
     dplyr::compute(name = name, temporary = FALSE) %>%
     omopgenerics::newCohortTable(.softValidation = TRUE) %>%
     omopgenerics::recordCohortAttrition(reason = reason, cohortId = cohortId)
