@@ -1,27 +1,27 @@
 test_that("unionCohorts works", {
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
-    omock::mockCohort(name = c("cohort1"), numberCohorts = 4)
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
+    omock::mockCohort(name = c("cohort1"), numberCohorts = 4, seed = 1)
   cdm <- cdm_local |> copyCdm()
-  # simple example
+   # simple example
   cdm$cohort2 <- unionCohorts(cdm$cohort1, name = "cohort2")
   expect_true(all(
     cdm$cohort2 %>% dplyr::pull("cohort_start_date") %>% sort() ==
-      c("1994-02-19", "1999-08-24", "2000-06-23", "2015-01-19")
+      c("1999-05-03", "2001-03-24", "2015-01-22")
   ))
   expect_true(all(
     cdm$cohort2 %>% dplyr::pull("cohort_end_date") %>% sort() ==
-      c("2001-08-26", "2006-09-27", "2007-08-06", "2015-09-14")
+      c("2002-06-07", "2009-06-12", "2015-06-22")
   ))
   expect_true(all(
-    cdm$cohort2 %>% dplyr::pull("subject_id") %>% sort() == 1:4
+    cdm$cohort2 %>% dplyr::pull("subject_id") %>% sort() == 1:3
   ))
   expect_true(all(attrition(cdm$cohort2) ==
                     dplyr::tibble(
                       cohort_definition_id = 1,
-                      number_records = 4,
-                      number_subjects = 4,
+                      number_records = 3,
+                      number_subjects = 3,
                       reason_id = 1,
                       reason = "Initial qualifying events",
                       excluded_records = 0,
@@ -33,20 +33,20 @@ test_that("unionCohorts works", {
   cdm$cohort3 <- unionCohorts(cdm$cohort1, cohortId = 1:2, name = "cohort3")
   expect_true(all(
     cdm$cohort3 %>% dplyr::pull("cohort_start_date") %>% sort() ==
-      c("1997-10-22", "2000-06-23", "2015-03-05")
+      c("1999-05-03", "2001-03-24", "2001-11-28", "2002-01-30", "2002-06-13", "2015-02-25")
   ))
   expect_true(all(
     cdm$cohort3 %>% dplyr::pull("cohort_end_date") %>% sort() ==
-      c("1999-05-28", "2006-09-27", "2015-07-06")
+      c("2001-06-15", "2001-11-27", "2002-01-29", "2002-06-12", "2005-07-19", "2015-04-30")
   ))
   expect_true(all(
-    cdm$cohort3 %>% dplyr::pull("subject_id") %>% sort() == c(1, 3, 4)
+    cdm$cohort3 %>% dplyr::pull("subject_id") %>% sort() == c(1, 1, 1, 1, 2, 3)
   ))
   expect_true(all(
     attrition(cdm$cohort3) ==
       dplyr::tibble(
         cohort_definition_id = 1,
-        number_records = 3,
+        number_records = 6,
         number_subjects = 3,
         reason_id = 1,
         reason = "Initial qualifying events",
@@ -55,19 +55,26 @@ test_that("unionCohorts works", {
       )))
   expect_true(settings(cdm$cohort3)$cohort_name == "cohort_1_cohort_2")
 
-  # 1 cohort
-  cdm$cohort4 <- unionCohorts(cdm$cohort1, cohortId = 2, cohortName = "newname", name = "cohort4")
-  expect_equal(settings(cdm$cohort4), dplyr::tibble(cohort_definition_id = 1, cohort_name = "newname"))
-  expect_true(attrition(cdm$cohort4)$cohort_definition_id == 1)
-  expect_true(cohortCount(cdm$cohort4)$cohort_definition_id == 1)
+  cdm$cohort4 <- unionCohorts(cdm$cohort1, cohortId = c("cohort_1", "cohort_2"), name = "cohort4")
+  expect_equal(collectCohort(cdm$cohort3, 1), collectCohort(cdm$cohort4, 1))
+  expect_equal(collectCohort(cdm$cohort3, 2), collectCohort(cdm$cohort4, 2))
+
+  # union 2 empty cohorts
+  cdm$cohort5 <- conceptCohort(cdm = cdm, conceptSet = list("a"= 1, "b" = 2), name = "cohort5")
+  cdm$cohort6 <- cdm$cohort5 |> unionCohorts(name = "cohort6")
+  expect_true(nrow(attrition(cdm$cohort6)) == 1)
+  expect_true(attrition(cdm$cohort6)$number_records == 0)
+
+  cdm$cohort5 <- cdm$cohort5 |> unionCohorts(name = "cohort5")
+
 
   PatientProfiles::mockDisconnect(cdm)
 })
 
 test_that("gap and name works", {
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
     omock::mockCohort(name = c("cohort"), numberCohorts = 4, seed = 11, recordPerson = 2)
   cdm_local$cohort <- cdm_local$cohort |>
     dplyr::arrange(.data$subject_id, .data$cohort_start_date) |>
@@ -113,21 +120,21 @@ test_that("gap and name works", {
   cdm$cohort <- unionCohorts(cdm$cohort, gap = 2,  cohortName = "test")
   expect_true(all(
     cdm$cohort %>% dplyr::pull("cohort_start_date") %>% sort() ==
-      c("1991-10-17", "1991-12-11", "1993-02-17", "1999-04-12", "1999-08-23",
-        "1999-09-19", "2001-12-27", "2015-03-02", "2015-03-17")
+      c("1991-07-14", "1991-10-21", "1995-01-27", "1999-07-26", "1999-08-22",
+        "2002-08-29", "2003-02-07", "2015-02-04", "2015-02-16", "2015-03-07")
   ))
   expect_true(all(
     cdm$cohort %>% dplyr::pull("cohort_end_date") %>% sort() ==
-      c("1991-10-19", "1992-10-12", "1999-07-18", "1999-08-24", "2001-03-19",
-        "2001-06-05", "2008-08-28", "2015-03-09", "2015-03-25")
+      c("1991-08-14", "1994-05-05", "1995-09-11", "1999-08-15", "2001-07-23",
+        "2002-12-29", "2007-06-11", "2015-02-12", "2015-02-26", "2015-07-28")
   ))
   expect_true(all(
-    cdm$cohort %>% dplyr::pull("subject_id") %>% sort() == c(1, rep(2, 3), rep(3, 2), rep(4, 3))
+    cdm$cohort %>% dplyr::pull("subject_id") %>% sort() == c(1, 1, rep(2, 2), rep(3, 3), rep(4, 3))
   ))
   expect_true(all(attrition(cdm$cohort) ==
                     dplyr::tibble(
                       cohort_definition_id = 1,
-                      number_records = 9,
+                      number_records = 10,
                       number_subjects = 4,
                       reason_id = 1,
                       reason = "Initial qualifying events",
@@ -142,19 +149,17 @@ test_that("gap and name works", {
 test_that("Expected behaviour", {
   testthat::skip_on_cran()
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
     omock::mockCohort(name = c("cohort"), numberCohorts = 4, seed = 8, recordPerson = 2)
   cdm <- cdm_local |> copyCdm()
-  expect_warning(
+  expect_error(
     cohort <- unionCohorts(cdm$cohort,
                            cohortId = 1,
                            gap = 0,
                            cohortName = NULL,
                            name = "cohort1")
   )
-  expect_true(cohort |> dplyr::anti_join(cdm$cohort, by = colnames(cohort)) |>
-                dplyr::tally() |> dplyr::pull("n") == 0)
   expect_error(
     cohort <- unionCohorts(cdm$cohort,
                            cohortId = NULL,
@@ -197,9 +202,9 @@ test_that("Expected behaviour", {
 test_that("test codelist", {
   testthat::skip_on_cran()
   cdm_local <- omock::mockCdmReference() |>
-    omock::mockPerson(n = 4) |>
-    omock::mockObservationPeriod() |>
-    omock::mockCohort()
+    omock::mockPerson(n = 4,seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
+    omock::mockCohort(seed = 1)
   cdm_local$concept <- dplyr::tibble(
     "concept_id" = c(1, 2, 3),
     "concept_name" = c("my concept 1", "my concept 2", "my concept 3"),
@@ -253,14 +258,14 @@ test_that("test codelist", {
   cdm$cohort4 <- unionCohorts(cdm$cohort3, name = "cohort4")
   expect_true(all(
     cdm$cohort4 %>% dplyr::pull("cohort_start_date") %>% sort() ==
-      c("1997-10-22", "2001-03-30", "2003-06-15", "2009-12-22", "2010-01-01", "2010-01-11", "2010-05-31", "2012-09-27", "2014-12-06", "2015-03-25")
+      c("1999-05-03", "2003-05-17", "2004-03-11", "2009-12-22", "2010-01-01", "2010-01-11", "2010-05-31", "2012-09-27", "2014-12-06", "2015-02-25")
   ))
   expect_true(all(
     cdm$cohort4 %>% dplyr::pull("cohort_end_date") %>% sort() ==
-      c("1999-05-28", "2003-06-14", "2005-11-23", "2010-05-04", "2011-08-24", "2014-02-09", "2014-05-20", "2014-12-10", "2015-04-14", "2015-06-24")
+      c("2001-06-15", "2004-03-10", "2005-07-19", "2010-05-04", "2011-08-24", "2014-02-09", "2014-05-20", "2014-12-10", "2015-04-30", "2015-06-24")
   ))
   expect_true(all(
-    cdm$cohort4 %>% dplyr::pull("subject_id") %>% sort() == c(1, 1, 1, 1, 2, 3, 3, 3, 4, 4)
+    cdm$cohort4 %>% dplyr::pull("subject_id") %>% sort() == c(1, 1, 1, 1, 2, 2, 3, 3, 3, 4)
   ))
   codes <- attr(cdm$cohort4, "cohort_codelist")
   expect_true(all(codes |> dplyr::pull("codelist_name") |> sort() == c(rep("c1", 2), "c2")))
@@ -270,3 +275,25 @@ test_that("test codelist", {
 
   PatientProfiles::mockDisconnect(cdm)
 })
+
+test_that("keep original cohorts", {
+  cdm_local <- omock::mockCdmReference() |>
+    omock::mockPerson(n = 4, seed = 1) |>
+    omock::mockObservationPeriod(seed = 1) |>
+    omock::mockCohort(name = c("cohort1"), numberCohorts = 4,seed = 1)
+  cdm <- cdm_local |> copyCdm()
+
+  start_settings <- settings(cdm$cohort1)
+
+  cdm$cohort2 <- unionCohorts(cdm$cohort1,
+                              name = "cohort2",
+                              keepOriginalCohorts = FALSE)
+  expect_true(nrow(settings(cdm$cohort2)) == 1)
+
+  cdm$cohort3 <- unionCohorts(cdm$cohort1,
+                              name = "cohort3",
+                              keepOriginalCohorts = TRUE)
+  expect_true(nrow(settings(cdm$cohort3)) == nrow(start_settings) + 1)
+
+  PatientProfiles::mockDisconnect(cdm)
+})
